{% extends base_template %}


{% block check_link_breadcrumb %}
    {{ super() }}
    <li class="active">
        {{ _("Global") }}
    </li>
{% endblock %}


{% block check_link_content %}

    <div class="check-link-reports">
        {% for report in page %}
            <div class="check-link-reports--item">
                {% include "check_link/snippets/report_item.html" %}
            </div>
        {% else %}
            <p class="text-center text-muted">
                {{ _("At the moment there are no available reports") }}
            </p>
        {% endfor %}
    </div>
    {% block check_link_pagination %}
        {{ page.pager() }}
    {% endblock %}
{% endblock check_link_content %}



{% block check_link_help_text %}
    {% trans %}
    <p>
        Brief overview of the current state of the links within the portal.
    </p>

    <p>
        Possible states are:

        <dl>
            <dt>Unknown</dt>
            <dd>Link has not been checked yet</dd>

            <dt>Available</dt>
            <dd>Link is available</dd>

            <dt>Moved</dt>
            <dd>Link contains a redirect to the differens URL</dd>

            <dt>Missing</dt>
            <dd>Link points to the page that does not exist</dd>

            <dt>Protected</dt>
            <dd>Link points to the page that requires authentication</dd>

            <dt>Invalid</dt>
            <dd>Link points to an existing location, but requests are rejected</dd>

            <dt>Error</dt>
            <dd>Link cannot be checked because it mailformed or points to an unexisting location</dd>
        </dl>
    </p>
    {% endtrans %}

{% endblock check_link_help_text %}
